@@ -50,14 +50,14 @@ class SpecificChord(Cached):
         if isinstance(root, str):
             root = Note(root)
 
-        notes_abstract = SpecificNote.to_astract(notes)
+        notes_abstract = SpecificNote.to_abstract(notes)
         if root is not None and root not in notes_abstract:
             raise KeyError('root should be one of notes')
 
         self.notes = notes
         self.root = root
         self.abstract = Chord(notes_abstract, root=root)
-        self.root_specific = frozenset(note for note in notes if note.abstract == root)
+        self.root_specific = frozenset(note for note in notes if note.abstract == root) if root is not None else frozenset()
 
         self.notes_ascending = tuple(sorted(notes))
         self.intervals = tuple(note - self.notes_ascending[0] for note in self.notes_ascending[1:])  # from lowest note
